@@ -14,13 +14,10 @@
 # limitations under the License.
 #
 
-
-import shlex
-import sys
-
 from ovirtcli.shell.cmdshell import CmdShell
 from ovirtcli.utils.autocompletionhelper import AutoCompletionHelper
 
+
 class ConnectCmdShell(CmdShell):
     NAME = 'connect'
     OPTIONS = [
@@ -34,31 +31,15 @@ class ConnectCmdShell(CmdShell):
        'filter',
        'port',
        'timeout',
-       'session-timeout'
+       'session-timeout',
+       'kerberos',
     ]
 
-    def __init__(self, context, parser):
-        CmdShell.__init__(self, context, parser)
-
-    def __do_verbose_connect(self, context, parser, opts):
-        if not self.copy_environment_vars(context):
-            sys.exit(1)
-        if not self.copy_cmdline_options(opts, context, parser):
-            sys.exit(1)
-        self.context.execute_string(ConnectCmdShell.NAME + '\n')
-
-    def __do_connect(self, args):
-        arg = ConnectCmdShell.NAME + ' ' + args.strip() + '\n'
-        self.context.execute_string(arg)
+    def __init__(self, context):
+        CmdShell.__init__(self, context)
 
     def do_connect(self, args):
-        arg = '--connect ' + args.strip() + '\n'
-        m_opts, m_args = self.parser.parse_args(args=shlex.split(arg))
-
-        if m_opts.connect and len(m_args) == 0:
-            self.__do_verbose_connect(self.context, self.parser, m_opts)
-        else:
-            self.__do_connect(args)
+        self.context.execute_string(ConnectCmdShell.NAME + ' ' + args + '\n')
 
     def complete_connect(self, text, line, begidx, endidx):
         return AutoCompletionHelper.complete(line=line, text=text,
